==> huaweicloudsdkccm-3.0.51-py2.py3-none-any.whl: huaweicloudsdkccm/v1/model/show_certificate_authority_obs_agency_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ShowCertificateAuthorityObsAgencyResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'agency_granted': 'str'
    }

    attribute_map = {
        'agency_granted': 'agency_granted'
    }

    def __init__(self, agency_granted=None):
        """ShowCertificateAuthorityObsAgencyResponse - a model defined in huaweicloud sdk"""
        
        super(ShowCertificateAuthorityObsAgencyResponse, self).__init__()

        self._agency_granted = None
        self.discriminator = None

        if agency_granted is not None:
            self.agency_granted = agency_granted

    @property
    def agency_granted(self):
        """Gets the agency_granted of this ShowCertificateAuthorityObsAgencyResponse.

        是否已授权

        :return: The agency_granted of this ShowCertificateAuthorityObsAgencyResponse.
        :rtype: str
        """
        return self._agency_granted

    @agency_granted.setter
    def agency_granted(self, agency_granted):
        """Sets the agency_granted of this ShowCertificateAuthorityObsAgencyResponse.

        是否已授权

        :param agency_granted: The agency_granted of this ShowCertificateAuthorityObsAgencyResponse.
        :type: str
        """
        self._agency_granted = agency_granted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCertificateAuthorityObsAgencyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkccm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkccm/v1/model/show_certificate_authority_obs_agency_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCertificateAuthorityObsAgencyResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'agency_granted': 'str'
    }

    attribute_map = {
        'agency_granted': 'agency_granted'
    }

    def __init__(self, agency_granted=None):
        """ShowCertificateAuthorityObsAgencyResponse - a model defined in huaweicloud sdk"""
        
        super(ShowCertificateAuthorityObsAgencyResponse, self).__init__()

        self._agency_granted = None
        self.discriminator = None

        if agency_granted is not None:
            self.agency_granted = agency_granted

    @property
    def agency_granted(self):
        """Gets the agency_granted of this ShowCertificateAuthorityObsAgencyResponse.

        是否已授权

        :return: The agency_granted of this ShowCertificateAuthorityObsAgencyResponse.
        :rtype: str
        """
        return self._agency_granted

    @agency_granted.setter
    def agency_granted(self, agency_granted):
        """Sets the agency_granted of this ShowCertificateAuthorityObsAgencyResponse.

        是否已授权

        :param agency_granted: The agency_granted of this ShowCertificateAuthorityObsAgencyResponse.
        :type: str
        """
        self._agency_granted = agency_granted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCertificateAuthorityObsAgencyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
